@@ -12,7 +12,7 @@ test_that("common gives the desired output",{
     expect_true(all(unique(y[, 2]) == 3))
     
     r <- list(a, b, d)
-    expect_true(identical(common(r), y))
+    expect_equivalent(common(r), y)
     
     expect_true(is.data.frame(common(word_list(DATA$state, DATA$person)$cwl, 
         overlap = 2)))
